@@ -1,6 +1,6 @@
 #define QT_FEATURE_ffmpeg 1
 
-#define QT_FEATURE_pipewire -1
+#define QT_FEATURE_pipewire 1
 
 #define QT_FEATURE_alsa -1
 
@@ -14,7 +14,7 @@
 
 #define QT_FEATURE_gstreamer 1
 
-#define QT_FEATURE_gstreamer_photography -1
+#define QT_FEATURE_gstreamer_photography 1
 
 #define QT_FEATURE_gstreamer_gl 1
 
